/**
 * Converts an angle value to degrees
 *
 * @param angle - numeric angle value
 * @param unit - angle unit to convert from
 * @returns converted angle value in degrees
 */
export declare function toDegrees(angle: number, unit: string): number;
/**
 * Normalizes angle value (in degrees) to range [0..360)
 *
 * @param degrees - numeric angle value
 * @returns normalized angle value
 */
export declare function normalizeAngle(degrees: number): number;
/**
 * Extracts the numeric value (in degrees) from an angle
 * string
 *
 * The following CSS angle units are supported: `deg`,
 * `rad`, `grad`, and `turn`. Default unit is `deg`.
 * Unit conversion is done as necessary.
 *
 * @param str - CSS angle string
 * @returns numeric value normalized to range [0..360), or `NaN`
 */
export default function angle(str: string): number;
