/** Color string in `hsl()` or `hsla()` format */
export declare type HslString = `hsl(${string})` | `hsla(${string})`;
/**
 * Regular expression for HSL color string
 *
 * The pattern is less strict than actual CSS, mainly for
 * performance reasons. Notably, it does NOT impose
 * consistent separator (comma vs. space).
 */
export declare const hslMatcher: RegExp;
/**
 * Checks if a given string is a valid HSL color string
 *
 * @param colorString
 * @returns true/false (type predicate for `HslString` in TS)
 */
export declare function isHslString(colorString: string): colorString is HslString;
/**
 * Attempts to match the given color string with the HSL
 * string pattern, and extracts the color components
 *
 * Since the standard unit for S and L values is percent,
 * the % sign is not included in the captured values.
 *
 * @param colorString
 * @returns an array containing the matched HSL values, or `null`
 */
export declare function matchHslString(colorString: string): string[] | null;
