/** Color string in `rgb()` or `rgba()` format */
export declare type RgbString = `rgb(${string})` | `rgba(${string})`;
/**
 * Regular expression for RGB color string
 *
 * The pattern is less strict than actual CSS, mainly for
 * performance reasons. Notably, it does NOT impose:
 * - consistent separator (comma vs. space)
 * - consistent unit of color components (number value vs. percentage)
 */
export declare const rgbMatcher: RegExp;
/**
 * Checks if a given string is a valid RGB color string
 *
 * @param colorString
 * @returns true/false (type predicate for `RgbString` in TS)
 */
export declare function isRgbString(colorString: string): colorString is RgbString;
/**
 * Attempts to match the given color string with the RGB
 * string pattern, and extracts the color components
 *
 * @param colorString
 * @returns an array containing the matched RGB values, or `null`
 */
export declare function matchRgbString(colorString: string): string[] | null;
