import type { ColorMapping } from '../palette';
/**
 * Generates a color that is complementary to the base color
 *
 * A complementary color is one that is located at the
 * opposite side of the color wheel, i.e. at 180˚ angle.
 * This provides excellent color contrast.
 *
 * This mapping function cycles through multiple sets of
 * "double complementary" hue rotation. The algorithm loops
 * from 1 to `key`, rotates Hue by 180˚ on every odd
 * iteration, and 30˚ on even. A negative `key` value
 * rotates in the opposite direction.
 *
 * @param baseColor
 * @param key - rotation steps
 * @returns new color value in hex
 * @throws if `baseColor` is not a valid color value
 */
declare const complement: ColorMapping;
export default complement;
